@@ -12,7 +12,7 @@
 #' @references
 #' Kery, M., and Schaub, M. 2011.
 #' Bayesian population analysis using WinBUGS: a hierarchical perspective.
-#' Academic Press, Boston. Available from <https://www.vogelwarte.ch/de/projekte/publikationen/bpa/>.
+#' Academic Press, Boston. Available from <https://www.vogelwarte.ch/en/research/population-biology/book-bpa/>.
 #' @export
 #' @examples
 #' pvalue(as.numeric(0:100))
@@ -20,8 +20,10 @@ pvalue <- function(x, threshold = 0, na_rm = FALSE) {
   chk_numeric(x)
   chk_number(threshold)
 
-  if(anyNA(x)) {
-    if(vld_false(na_rm)) return(NA_real_)
+  if (anyNA(x)) {
+    if (vld_false(na_rm)) {
+      return(NA_real_)
+    }
     x <- as.vector(x)
     x <- x[!is.na(x)]
   }
