@@ -11,11 +11,15 @@
 #' zeros(c(0:2))
 zeros <- function(x, na_rm = FALSE) {
   chk_numeric(x)
-  if(anyNA(x)) {
-    if(vld_false(na_rm)) return(NA_integer_)
+  if (anyNA(x)) {
+    if (vld_false(na_rm)) {
+      return(NA_integer_)
+    }
     x <- as.vector(x)
     x <- x[!is.na(x)]
   }
-  if(!length(x)) return(0L)
+  if (!length(x)) {
+    return(0L)
+  }
   sum(x == 0)
 }
