@@ -5,15 +5,8 @@ test_that("chk_pars", {
   expect_null(chk_pars(c("a", "A")))
   expect_null(chk_pars("a1._"))
 
-  expect_error(chk_pars(NA_character_),
-    "^`NA_character_` must not have any missing values[.]$",
-    class = "chk_error"
-  )
-  x <- c("a", "a")
-  expect_error(chk_pars(x),
-    "^`x` must be unique[.]$",
-    class = "chk_error"
-  )
+  expect_null(chk_pars(NA_character_))
+  expect_null(chk_pars(c("a", "a")))
   x <- factor("a")
   expect_error(chk_pars(x),
     "^`x` must inherit from S3 class 'character'[.]$",
@@ -30,9 +23,9 @@ test_that("chk_pars", {
 test_that("vld_pars", {
   expect_true(vld_pars(character(0)))
   expect_false(vld_pars(factor(0)))
-  expect_false(vld_pars(NA_character_))
+  expect_true(vld_pars(NA_character_))
   expect_true(vld_pars("a"))
-  expect_false(vld_pars(c("a", "a")))
+  expect_true(vld_pars(c("a", "a")))
   expect_true(vld_pars(c("a", "A")))
   expect_false(vld_pars("a[1]"))
   expect_true(vld_pars("a1._"))
